searchData={"items":[{"type":"module","title":"cozodb","doc":"CozoDB  is a A FOSS embeddable,\ntransactional, relational-graph-vector database with time travelling capability,\nperfect as the long-term memory for LLMs and AI.\n\nThis module implements the Erlang (BEAM) bindings for CozoDB via a NIF built using [Rustler](https://github.com/rusterlium/rustler).","ref":"cozodb.html"},{"type":"module","title":"Key Features - cozodb","doc":"- **Transactional Operations:** Supports atomic transactions for batch operations\n- **Hybrid Data Model:** Combines relational, graph, and vector paradigms\n- **Time Travelling:** Query historical versions of your data\n- **Flexible Indexing:** with support for\n  - Covering Indices\n  - Proximity Indices:\n    - HNSW (Hierarchical Navigable Small World): Fast approximate nearest neighbor searches\n    - MinHash-LSH: Locality sensitive hashing for similarity searches\n    - Full-Text Search (FTS): Efficient text matching","ref":"cozodb.html#module-key-features"},{"type":"module","title":"Usage Overview - cozodb","doc":"The API is divided into several sections:","ref":"cozodb.html#module-usage-overview"},{"type":"module","title":"Database Lifecycle - cozodb","doc":"- **Opening/Closing:**\n  Use `open/0`, `open/1`, `open/2`, and `open/3` to create or open a database.\n  Use `close/1` to gracefully shut down a database, freeing allocated NIF resources.\n\n- **Backup & Restore:**\n  Functions such as `backup/2`, `restore/2`, and `import_from_backup/3` enable exporting and restoring your database.","ref":"cozodb.html#module-database-lifecycle"},{"type":"module","title":"Data Operations - cozodb","doc":"- **Import/Export:**\n  The `import/2` and `export/2,3` functions allow for batch data ingestion and extraction, ensuring consistency via transactions.\n\n- **Running Scripts:**\n  Use `run/2` and `run/3` to execute CozoScript commands for querying or modifying the database.","ref":"cozodb.html#module-data-operations"},{"type":"module","title":"System Catalogue - cozodb","doc":"- **Relations and Columns:**\n  Functions like `relations/1`, `columns/2`, and `describe/3` let you inspect and manage stored relations.\n\n- **Indices and Triggers:**\n  Create indices using `create_index/4` and manage triggers via `triggers/2`, `set_triggers/3`, and `delete_triggers/2`.","ref":"cozodb.html#module-system-catalogue"},{"type":"module","title":"Advanced Features - cozodb","doc":"- **Query Explanation:**\n  The `explain/2` function provides insights into query execution.\n\n- **Monitoring & Maintenance:**\n  Functions such as `running/1`, `kill/2`, and `compact/1` help monitor and maintain database health.","ref":"cozodb.html#module-advanced-features"},{"type":"module","title":"Indexing Examples - cozodb","doc":"","ref":"cozodb.html#module-indexing-examples"},{"type":"module","title":"Datalog Programs - cozodb","doc":"See the [CozoScript Tutorial](https://docs.cozodb.org/en/latest/tutorial.html).","ref":"cozodb.html#module-datalog-programs"},{"type":"module","title":"HSNW - cozodb","doc":"```\n{ok, _} = Module:create_index(Db, \"table_hnsw_fun\", \"my_hsnw_index\", #{\n    type => hnsw,\n    dim => 128,\n    m => 50,\n    ef_construction => 20,\n    dtype => f32,\n    distance => l2,\n    fields => [v],\n    filter => <<\"k != `foo`\">>,\n    extend_candidates => false,\n    keep_pruned_connections => false\n}).\n```","ref":"cozodb.html#module-hsnw"},{"type":"module","title":"LSH Indices - cozodb","doc":"```\n{ok, _} = Module:create_index(Db, \"table_lsh_fun\", \"my_lsh_index\", #{\n    type => lsh,\n    extractor => v,\n    extract_filter => \"!is_null(v)\",\n    tokenizer => simple,\n    filters => [alphanumonly],\n    n_perm => 200,\n    target_threshold => 0.7,\n    n_gram => 3,\n    false_positive_weight => 1.0,\n    false_negative_weight => 1.0\n}).\n```","ref":"cozodb.html#module-lsh-indices"},{"type":"module","title":"FTS Indices - cozodb","doc":"You can create an FTS index using `create_index/4`.\n\nThe following example creates and index called `my_fts_index` on the relation\n`rel_a`.\n\n```\n{ok, _} = Module:create_index(Db, \"rel_a\", \"my_fts_index\", #{\n    type => fts,\n    extractor => v,\n    extract_filter => \"!is_null(v)\",\n    tokenizer => simple,\n    filters => [alphanumonly]\n}).\n```\n\nYou can always use Cozo Script directly via `run/2`. For example, the\nfollowing script is equivalent to the previous example.\n\n```\n::fts create rel_a:my_fts_index {\n    extractor: v,\n    extract_filter: !is_null(v),\n    tokenizer: Simple,\n    filters: [],\n}\n```\nFor more details, see the  FTS documentation .","ref":"cozodb.html#module-fts-indices"},{"type":"module","title":"System Operations - cozodb","doc":"* Query Management: Monitor running queries with running/1 and terminate problematic queries using kill/2.","ref":"cozodb.html#module-system-operations"},{"type":"function","title":"cozodb.backup/2","doc":"Exports the database to a SQLite file at `Path`.\nTo restore the database using this file see {@link restore/2}.","ref":"cozodb.html#backup/2"},{"type":"function","title":"cozodb.close/1","doc":"Closes the database.\nNotice that the call is asyncronous and the database might take a while to\nclose and a subsequent invocation to {@link open/3} with the same `path`\nmight fail.","ref":"cozodb.html#close/1"},{"type":"function","title":"cozodb.columns/2","doc":"List columns for relation","ref":"cozodb.html#columns/2"},{"type":"function","title":"cozodb.compact/1","doc":"","ref":"cozodb.html#compact/1"},{"type":"function","title":"cozodb.create_index/4","doc":"Create index for relation","ref":"cozodb.html#create_index/4"},{"type":"function","title":"Hierarchical Navigable Small World (HNSW) Index - cozodb.create_index/4","doc":"The parameters are:\n* The dimension `dim` and the data type `dtype` (defaults to `F32`) has to\nmatch the dimensions of any vector you index\n* The fields parameter is a list of fields in the table that should be\nindexed\n* The indexed fields must only contain vectors of the same dimension and\ndata type, or null, or a list of vectors of the same dimension and data\ntype\n* The distance parameter is the distance metric to use: the options are L2 (\ndefault), Cosine and IP\n* The m controls the maximal number of outgoing connections from each node\nin the graph\n* The ef_construction parameter is the number of nearest neighbors to use\nwhen building the index: see the HNSW paper for details\n* The filter parameter, when given, is bound to the fields of the original\nrelation and only those rows for which the expression evaluates to true are\nindexed\n* The extend_candidates parameter is a boolean (default false) that\ncontrols whether the index should extend the candidate list with the nearest\nneighbors of the nearest neighbors\n* The keep_pruned_connections parameter is a boolean (default false) that\ncontrols whether the index should keep pruned connections.\n\n#### Example\n```\n1> Spec = #{\n type => hnsw,\n dim => 128,\n m => 50,\n ef_construction => 20,\n dtype => f32,\n distance => l2,\n fields => [v],\n filter => <<\"k != `foo`\">>,\n extend_candidates => false,\n keep_pruned_connections => false\n}.\n2> create_index(Db, my_relation, Spec).\nok\n```","ref":"cozodb.html#create_index/4-hierarchical-navigable-small-world-hnsw-index"},{"type":"function","title":"cozodb.create_relation/3","doc":"","ref":"cozodb.html#create_relation/3"},{"type":"function","title":"cozodb.delete_triggers/2","doc":"Calls `set_triggers/3` with and empty specs list.","ref":"cozodb.html#delete_triggers/2"},{"type":"function","title":"cozodb.describe/3","doc":"Create index for relation","ref":"cozodb.html#describe/3"},{"type":"function","title":"cozodb.drop_index/2","doc":"Drop index with fully qualified name.","ref":"cozodb.html#drop_index/2"},{"type":"function","title":"cozodb.drop_index/3","doc":"Create index for relation","ref":"cozodb.html#drop_index/3"},{"type":"function","title":"cozodb.explain/2","doc":"","ref":"cozodb.html#explain/2"},{"type":"function","title":"cozodb.export/2","doc":"Export the specified relations in `Relations`.\nIt is guaranteed that the exported data form a consistent snapshot of what\nwas stored in the database.\nReturns a map with binary keys for the names of relations, and values as maps\ncontaining the `headers` and `rows` of the relation.","ref":"cozodb.html#export/2"},{"type":"function","title":"cozodb.export/3","doc":"Export the specified relations in `Relations`.\nIt is guaranteed that the exported data form a consistent snapshot of what\nwas stored in the database.\nReturns a map with binary keys for the names of relations, and values as maps\ncontaining the `headers` and `rows` of the relation.","ref":"cozodb.html#export/3"},{"type":"function","title":"cozodb.import/2","doc":"Import data into a database. The data are imported inside a transaction, so\nthat either all imports are successful, or none are. If conflicts arise\nbecause of concurrent modification to the database, via either CosoScript\nqueries or other imports, the transaction will fail.\nThe relations to import into must exist beforehand, and the data given must\nmatch the schema defined.\nThis API can be used to batch-put or remove data from several stored\nrelations atomically. The data parameter can contain relation names such as\n\"rel_a\", or relation names prefixed by a minus sign such as \"-rel_a\". For the\nformer case, every row given for the relation will be put into the database,\ni.e. upsert semantics. For the latter case, the corresponding rows are\nremoved from the database, and you should only specify the key part of the\nrows. As for rm in CozoScript, it is not an error to remove non-existent\nrows.\n%%","ref":"cozodb.html#import/2"},{"type":"function","title":"Erlang Example === - cozodb.import/2","doc":"```\n#{\n   rel_a => #{\n       headers => [\"x\", \"y\"],\n       rows => [[1, 2], [3, 4]]\n   },\n   rel_b => #{\n       headers => [\"z\"],\n       rows => []\n   }\n}\n```","ref":"cozodb.html#import/2-erlang-example"},{"type":"function","title":"cozodb.import_from_backup/3","doc":"","ref":"cozodb.html#import_from_backup/3"},{"type":"function","title":"cozodb.indices/2","doc":"List indices for relation","ref":"cozodb.html#indices/2"},{"type":"function","title":"cozodb.info/1","doc":"Closes the database.\nNotice that the call is asyncronous and the database might take a while to\nclose and a subsequent invocation to {@link open/3} with the same `path`\nmight fail.","ref":"cozodb.html#info/1"},{"type":"function","title":"cozodb.kill/2","doc":"Kill the running query associated with identifier `Id`.\nSee `running/1` to get the list of running queries and their\nidentifiers.","ref":"cozodb.html#kill/2"},{"type":"function","title":"cozodb.open/0","doc":"Opens a database with the default engine (aka backend).","ref":"cozodb.html#open/0"},{"type":"function","title":"cozodb.open/1","doc":"Opens a database with the provided Engine (aka backend) in the `/tmp` path.","ref":"cozodb.html#open/1"},{"type":"function","title":"cozodb.open/2","doc":"Opens a database with the provided Engine (aka backend) and path.","ref":"cozodb.html#open/2"},{"type":"function","title":"cozodb.open/3","doc":"Creates or opens an existing database.\n\nThe database has to be explicitely closed using `close/1` for Erlang\nto release the allocated ErlNIF resources.\n* `Path` is ignored when `Engine` is `mem`\n* `Opts` apply only to `tikv` engine","ref":"cozodb.html#open/3"},{"type":"function","title":"RocksDB - cozodb.open/3","doc":"To define options for RocksDB you should make sure a RocksDB configuration file\nnamed `config` is present at `Path` before you call this function.","ref":"cozodb.html#open/3-rocksdb"},{"type":"function","title":"cozodb.register_callback/2","doc":"","ref":"cozodb.html#register_callback/2"},{"type":"function","title":"cozodb.relations/1","doc":"List all existing relations.","ref":"cozodb.html#relations/1"},{"type":"function","title":"cozodb.remove_relation/2","doc":"Removes a relation","ref":"cozodb.html#remove_relation/2"},{"type":"function","title":"cozodb.remove_relations/2","doc":"List columns for relation","ref":"cozodb.html#remove_relations/2"},{"type":"function","title":"cozodb.resource/1","doc":"Returns the CozoDB DBInstance as a NIF Resource.\nFor testing and planned extensions, you SHALL NOT use this function.","ref":"cozodb.html#resource/1"},{"type":"function","title":"cozodb.restore/2","doc":"","ref":"cozodb.html#restore/2"},{"type":"function","title":"cozodb.rows_to_maps/1","doc":"Util function that takes a query_result() as argument and returns a list\nof rows as maps.","ref":"cozodb.html#rows_to_maps/1"},{"type":"function","title":"cozodb.run/2","doc":"","ref":"cozodb.html#run/2"},{"type":"function","title":"cozodb.run/3","doc":"","ref":"cozodb.html#run/3"},{"type":"function","title":"cozodb.running/1","doc":"","ref":"cozodb.html#running/1"},{"type":"function","title":"cozodb.set_triggers/3","doc":"","ref":"cozodb.html#set_triggers/3"},{"type":"function","title":"cozodb.triggers/2","doc":"Returns the list of triggers.","ref":"cozodb.html#triggers/2"},{"type":"function","title":"cozodb.unregister_callback/2","doc":"","ref":"cozodb.html#unregister_callback/2"},{"type":"type","title":"cozodb.column_atomic_type/0","doc":"","ref":"cozodb.html#t:column_atomic_type/0"},{"type":"type","title":"cozodb.column_composite_type/0","doc":"","ref":"cozodb.html#t:column_composite_type/0"},{"type":"type","title":"cozodb.column_name/0","doc":"","ref":"cozodb.html#t:column_name/0"},{"type":"type","title":"cozodb.column_spec/0","doc":"","ref":"cozodb.html#t:column_spec/0"},{"type":"type","title":"cozodb.column_type/0","doc":"","ref":"cozodb.html#t:column_type/0"},{"type":"type","title":"cozodb.covering_index_spec/0","doc":"","ref":"cozodb.html#t:covering_index_spec/0"},{"type":"opaque","title":"cozodb.db_handle/0","doc":"","ref":"cozodb.html#t:db_handle/0"},{"type":"type","title":"cozodb.engine/0","doc":"","ref":"cozodb.html#t:engine/0"},{"type":"type","title":"cozodb.engine_opts/0","doc":"","ref":"cozodb.html#t:engine_opts/0"},{"type":"type","title":"cozodb.export_opts/0","doc":"","ref":"cozodb.html#t:export_opts/0"},{"type":"type","title":"cozodb.extract_filter/0","doc":"","ref":"cozodb.html#t:extract_filter/0"},{"type":"type","title":"cozodb.fts_index_spec/0","doc":"","ref":"cozodb.html#t:fts_index_spec/0"},{"type":"type","title":"cozodb.hnsw_filter/0","doc":"","ref":"cozodb.html#t:hnsw_filter/0"},{"type":"type","title":"cozodb.hnsw_index_spec/0","doc":"","ref":"cozodb.html#t:hnsw_index_spec/0"},{"type":"type","title":"cozodb.index_spec/0","doc":"","ref":"cozodb.html#t:index_spec/0"},{"type":"type","title":"cozodb.info/0","doc":"","ref":"cozodb.html#t:info/0"},{"type":"type","title":"cozodb.json/0","doc":"","ref":"cozodb.html#t:json/0"},{"type":"type","title":"cozodb.lsh_index_spec/0","doc":"","ref":"cozodb.html#t:lsh_index_spec/0"},{"type":"type","title":"cozodb.path/0","doc":"","ref":"cozodb.html#t:path/0"},{"type":"type","title":"cozodb.query_opts/0","doc":"","ref":"cozodb.html#t:query_opts/0"},{"type":"type","title":"cozodb.query_result/0","doc":"","ref":"cozodb.html#t:query_result/0"},{"type":"type","title":"cozodb.query_return/0","doc":"","ref":"cozodb.html#t:query_return/0"},{"type":"type","title":"cozodb.relation_name/0","doc":"","ref":"cozodb.html#t:relation_name/0"},{"type":"type","title":"cozodb.relation_spec/0","doc":"","ref":"cozodb.html#t:relation_spec/0"},{"type":"type","title":"cozodb.relations/0","doc":"","ref":"cozodb.html#t:relations/0"},{"type":"type","title":"cozodb.row/0","doc":"","ref":"cozodb.html#t:row/0"},{"type":"type","title":"cozodb.script/0","doc":"","ref":"cozodb.html#t:script/0"},{"type":"type","title":"cozodb.token_filter/0","doc":"","ref":"cozodb.html#t:token_filter/0"},{"type":"type","title":"cozodb.tokenizer/0","doc":"","ref":"cozodb.html#t:tokenizer/0"},{"type":"type","title":"cozodb.trigger_event/0","doc":"","ref":"cozodb.html#t:trigger_event/0"},{"type":"type","title":"cozodb.trigger_spec/0","doc":"","ref":"cozodb.html#t:trigger_spec/0"},{"type":"type","title":"cozodb.validity/0","doc":"","ref":"cozodb.html#t:validity/0"},{"type":"type","title":"cozodb.value/0","doc":"","ref":"cozodb.html#t:value/0"},{"type":"module","title":"cozodb_app","doc":null,"ref":"cozodb_app.html"},{"type":"function","title":"cozodb_app.start/2","doc":null,"ref":"cozodb_app.html#start/2"},{"type":"function","title":"cozodb_app.stop/1","doc":null,"ref":"cozodb_app.html#stop/1"},{"type":"module","title":"cozodb_callback_monitor","doc":"A transient worker that is used to listen to certain plum_db events and\nallow watchers to wait (blocking the caller) for certain conditions.\nThis is used by plum_db_app during the startup process to wait for the\nfollowing conditions:\n\n* Partition initisalisation – the worker subscribes to plum_db notifications\nand keeps track of each partition initialisation until they are all\ninitialised (or failed to initilised) and replies to all watchers with a\n`ok' or `{error, FailedPartitions}', where FailedPartitions is a map() which\nkeys are the partition number and the value is the reason for the failure.\n* Partition hashtree build – the worker subscribes to plum_db notifications\nand keeps track of each partition hashtree until they are all\nbuilt (or failed to build) and replies to all watchers with a\n`ok' or `{error, FailedHashtrees}', where FailedHashtrees is a map() which\nkeys are the partition number and the value is the reason for the failure.\n\nA watcher is any process which calls the functions wait_for_partitions/0,1\nand/or wait_for_hashtrees/0,1. Both functions will block the caller until\nthe above conditions are met.","ref":"cozodb_callback_monitor.html"},{"type":"function","title":"cozodb_callback_monitor.code_change/3","doc":"","ref":"cozodb_callback_monitor.html#code_change/3"},{"type":"function","title":"cozodb_callback_monitor.handle_call/3","doc":"","ref":"cozodb_callback_monitor.html#handle_call/3"},{"type":"function","title":"cozodb_callback_monitor.handle_cast/2","doc":"","ref":"cozodb_callback_monitor.html#handle_cast/2"},{"type":"function","title":"cozodb_callback_monitor.handle_continue/2","doc":"","ref":"cozodb_callback_monitor.html#handle_continue/2"},{"type":"function","title":"cozodb_callback_monitor.handle_info/2","doc":"","ref":"cozodb_callback_monitor.html#handle_info/2"},{"type":"function","title":"cozodb_callback_monitor.init/1","doc":"","ref":"cozodb_callback_monitor.html#init/1"},{"type":"function","title":"cozodb_callback_monitor.start_link/0","doc":"","ref":"cozodb_callback_monitor.html#start_link/0"},{"type":"function","title":"cozodb_callback_monitor.stop/0","doc":"","ref":"cozodb_callback_monitor.html#stop/0"},{"type":"function","title":"cozodb_callback_monitor.terminate/2","doc":"","ref":"cozodb_callback_monitor.html#terminate/2"},{"type":"type","title":"cozodb_callback_monitor.state/0","doc":"","ref":"cozodb_callback_monitor.html#t:state/0"},{"type":"module","title":"cozodb_script_utils","doc":"","ref":"cozodb_script_utils.html"},{"type":"function","title":"cozodb_script_utils.encode_index_spec/1","doc":"Encodes an index specification into a CozoScript–formatted iolist.","ref":"cozodb_script_utils.html#encode_index_spec/1"},{"type":"function","title":"Parameters - cozodb_script_utils.encode_index_spec/1","doc":"- `Spec` :: `map()` - An index specification map. The map must specify the\n  index `type` (e.g. covering, hnsw, fts, or lsh) and include all required keys\n  for that index type.","ref":"cozodb_script_utils.html#encode_index_spec/1-parameters"},{"type":"function","title":"Returns - cozodb_script_utils.encode_index_spec/1","doc":"- An `iolist()` representing the encoded index specification.\n- Raises an error (`no_return()`) if the specification is invalid.","ref":"cozodb_script_utils.html#encode_index_spec/1-returns"},{"type":"function","title":"Example - cozodb_script_utils.encode_index_spec/1","doc":"Spec = #{\n        type => hnsw,\n        dim => 128,\n        m => 50,\n        ef_construction => 20,\n        dtype => f32,\n        distance => l2,\n        fields => [v],\n        filter => <<\"k != 'foo'\">>,\n        extend_candidates => false,\n        keep_pruned_connections => false\n    },\n    Encoded = encode_index_spec(Spec).","ref":"cozodb_script_utils.html#encode_index_spec/1-example"},{"type":"function","title":"cozodb_script_utils.encode_relation_spec/1","doc":"Encodes a relation specification map into a CozoScript–formatted iolist.\n\n**Parameters:**\n- `Spec` :: `map()` - A relation specification map. It must include the keys\n  `keys` and `columns`. If either is missing, they are defaulted to empty lists.\n\n**Returns:**\n- An `iolist()` representing the encoded specification.\n- Raises an error (`no_return()`) if the specification is invalid.\n\n**Example:**\n\n    Spec = #{keys => [{a, undefined}], columns => [...]},\n    Encoded = encode_relation_spec(Spec).","ref":"cozodb_script_utils.html#encode_relation_spec/1"},{"type":"function","title":"cozodb_script_utils.encode_triggers_spec/1","doc":"Encodes a list of trigger specifications into a CozoScript–formatted string.","ref":"cozodb_script_utils.html#encode_triggers_spec/1"},{"type":"function","title":"Parameters - cozodb_script_utils.encode_triggers_spec/1","doc":"- `Specs` :: `[trigger_spec()]` - A list of trigger specifications, where each\nspecification is a tuple of the form `{Event, Script}`. Supported events include\n`on_put`, `on_rm` (or `on_remove`), and `on_replace`.","ref":"cozodb_script_utils.html#encode_triggers_spec/1-parameters"},{"type":"function","title":"Returns - cozodb_script_utils.encode_triggers_spec/1","doc":"- An iolist (string) with each encoded trigger separated by a newline.\n- Returns an empty list if no triggers are specified.","ref":"cozodb_script_utils.html#encode_triggers_spec/1-returns"},{"type":"function","title":"Example - cozodb_script_utils.encode_triggers_spec/1","doc":"encode_triggers_spec([{on_put, \"query goes here\"}]).\n    returns <<\"on put { query goes here }\">>","ref":"cozodb_script_utils.html#encode_triggers_spec/1-example"},{"type":"function","title":"cozodb_script_utils.to_cozo_string/1","doc":"","ref":"cozodb_script_utils.html#to_cozo_string/1"},{"type":"function","title":"cozodb_script_utils.to_cozo_string/2","doc":"Converts a given term into a CozoScript–compatible string representation using\n the specified mode.","ref":"cozodb_script_utils.html#to_cozo_string/2"},{"type":"function","title":"Parameters: - cozodb_script_utils.to_cozo_string/2","doc":"- `Term` :: _any_ - The term to convert.\n- `Mode` :: `single` | `raw` - The conversion mode:\n  - `single`: Encloses atoms and binaries in single quotes.\n  - `raw`: Wraps values in a custom marker.","ref":"cozodb_script_utils.html#to_cozo_string/2-parameters"},{"type":"function","title":"Returns: - cozodb_script_utils.to_cozo_string/2","doc":"- A binary containing the formatted string representation of the term.","ref":"cozodb_script_utils.html#to_cozo_string/2-returns"},{"type":"function","title":"Examples: - cozodb_script_utils.to_cozo_string/2","doc":"to_cozo_string(<<\"foo\">>, single) %% returns <<\" 'foo' \">>.\n    to_cozo_string(<<\"foo\">>, raw)    %% returns a raw formatted string.","ref":"cozodb_script_utils.html#to_cozo_string/2-examples"},{"type":"module","title":"cozodb_sup","doc":"The CozoDB top level supervisor.","ref":"cozodb_sup.html"},{"type":"function","title":"cozodb_sup.init/1","doc":"","ref":"cozodb_sup.html#init/1"},{"type":"function","title":"cozodb_sup.start_link/0","doc":"","ref":"cozodb_sup.html#start_link/0"},{"type":"extras","title":"cozodb","doc":"cozodb\n=====\n\nErlang/BEAM NIF bindings for CozoDB using Rustler.\n\nCozoDB is a FOSS embeddable, transactional, relational-graph-vector database, wiht a Datalog query engine and time travelling capability, perfect as the long-term memory for LLMs and AI.","ref":"readme.html"},{"type":"extras","title":"Installation - cozodb","doc":"","ref":"readme.html#installation"},{"type":"extras","title":"Requirements - cozodb","doc":"* Erlang OTP26 and/or Elixir (latest)\n* Rust 1.76.0\n* macOS packages: \n  * `liblz4`, \n  * `libssl`\n* Linux packages:\n  * `build-essential` \n  * `liblz4-dev` \n  * `libncurses-dev` \n  * `libsnappy-dev` \n  * `libssl-dev` \n  * `liburing-dev`\n  * `liburing-dev` \n  * `liburing2`\n  * `pkg-config`","ref":"readme.html#requirements"},{"type":"extras","title":"Erlang - cozodb","doc":"Add the following to your `rebar.config` file.\n\n```erlang\n{deps, [\n    {cozodb,\n      {git, \"https://github.com/leapsight/cozodb.git\", {branch, \"master\"}}\n    }\n]}.\n```","ref":"readme.html#erlang"},{"type":"extras","title":"Elixir - cozodb","doc":"Add the following to your `mix.exs` file.\n\n```elixir\n  defp deps do\n    [\n        {:cozodb,\n            git: \"https://github.com/leapsight/cozodb.git\",\n            branch: \"master\"\n        }\n    ]\n```","ref":"readme.html#elixir"},{"type":"extras","title":"cheatsheet","doc":"","ref":"cheatsheet.html"},{"type":"extras","title":"LICENSE","doc":"Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\n   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n   1. Definitions.\n\n      \"License\" shall mean the terms and conditions for use, reproduction,\n      and distribution as defined by Sections 1 through 9 of this document.\n\n      \"Licensor\" shall mean the copyright owner or entity authorized by\n      the copyright owner that is granting the License.\n\n      \"Legal Entity\" shall mean the union of the acting entity and all\n      other entities that control, are controlled by, or are under common\n      control with that entity. For the purposes of this definition,\n      \"control\" means (i) the power, direct or indirect, to cause the\n      direction or management of such entity, whether by contract or\n      otherwise, or (ii) ownership of fifty percent (50%) or more of the\n      outstanding shares, or (iii) beneficial ownership of such entity.\n\n      \"You\" (or \"Your\") shall mean an individual or Legal Entity\n      exercising permissions granted by this License.\n\n      \"Source\" form shall mean the preferred form for making modifications,\n      including but not limited to software source code, documentation\n      source, and configuration files.\n\n      \"Object\" form shall mean any form resulting from mechanical\n      transformation or translation of a Source form, including but\n      not limited to compiled object code, generated documentation,\n      and conversions to other media types.\n\n      \"Work\" shall mean the work of authorship, whether in Source or\n      Object form, made available under the License, as indicated by a\n      copyright notice that is included in or attached to the work\n      (an example is provided in the Appendix below).\n\n      \"Derivative Works\" shall mean any work, whether in Source or Object\n      form, that is based on (or derived from) the Work and for which the\n      editorial revisions, annotations, elaborations, or other modifications\n      represent, as a whole, an original work of authorship. For the purposes\n      of this License, Derivative Works shall not include works that remain\n      separable from, or merely link (or bind by name) to the interfaces of,\n      the Work and Derivative Works thereof.\n\n      \"Contribution\" shall mean any work of authorship, including\n      the original version of the Work and any modifications or additions\n      to that Work or Derivative Works thereof, that is intentionally\n      submitted to Licensor for inclusion in the Work by the copyright owner\n      or by an individual or Legal Entity authorized to submit on behalf of\n      the copyright owner. For the purposes of this definition, \"submitted\"\n      means any form of electronic, verbal, or written communication sent\n      to the Licensor or its representatives, including but not limited to\n      communication on electronic mailing lists, source code control systems,\n      and issue tracking systems that are managed by, or on behalf of, the\n      Licensor for the purpose of discussing and improving the Work, but\n      excluding communication that is conspicuously marked or otherwise\n      designated in writing by the copyright owner as \"Not a Contribution.\"\n\n      \"Contributor\" shall mean Licensor and any individual or Legal Entity\n      on behalf of whom a Contribution has been received by Licensor and\n      subsequently incorporated within the Work.\n\n   2. Grant of Copyright License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      copyright license to reproduce, prepare Derivative Works of,\n      publicly display, publicly perform, sublicense, and distribute the\n      Work and such Derivative Works in Source or Object form.\n\n   3. Grant of Patent License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      (except as stated in this section) patent license to make, have made,\n      use, offer to sell, sell, import, and otherwise transfer the Work,\n      where such license applies only to those patent claims licensable\n      by such Contributor that are necessarily infringed by their\n      Contribution(s) alone or by combination of their Contribution(s)\n      with the Work to which such Contribution(s) was submitted. If You\n      institute patent litigation against any entity (including a\n      cross-claim or counterclaim in a lawsuit) alleging that the Work\n      or a Contribution incorporated within the Work constitutes direct\n      or contributory patent infringement, then any patent licenses\n      granted to You under this License for that Work shall terminate\n      as of the date such litigation is filed.\n\n   4. Redistribution. You may reproduce and distribute copies of the\n      Work or Derivative Works thereof in any medium, with or without\n      modifications, and in Source or Object form, provided that You\n      meet the following conditions:\n\n      (a) You must give any other recipients of the Work or\n          Derivative Works a copy of this License; and\n\n      (b) You must cause any modified files to carry prominent notices\n          stating that You changed the files; and\n\n      (c) You must retain, in the Source form of any Derivative Works\n          that You distribute, all copyright, patent, trademark, and\n          attribution notices from the Source form of the Work,\n          excluding those notices that do not pertain to any part of\n          the Derivative Works; and\n\n      (d) If the Work includes a \"NOTICE\" text file as part of its\n          distribution, then any Derivative Works that You distribute must\n          include a readable copy of the attribution notices contained\n          within such NOTICE file, excluding those notices that do not\n          pertain to any part of the Derivative Works, in at least one\n          of the following places: within a NOTICE text file distributed\n          as part of the Derivative Works; within the Source form or\n          documentation, if provided along with the Derivative Works; or,\n          within a display generated by the Derivative Works, if and\n          wherever such third-party notices normally appear. The contents\n          of the NOTICE file are for informational purposes only and\n          do not modify the License. You may add Your own attribution\n          notices within Derivative Works that You distribute, alongside\n          or as an addendum to the NOTICE text from the Work, provided\n          that such additional attribution notices cannot be construed\n          as modifying the License.\n\n      You may add Your own copyright statement to Your modifications and\n      may provide additional or different license terms and conditions\n      for use, reproduction, or distribution of Your modifications, or\n      for any such Derivative Works as a whole, provided Your use,\n      reproduction, and distribution of the Work otherwise complies with\n      the conditions stated in this License.\n\n   5. Submission of Contributions. Unless You explicitly state otherwise,\n      any Contribution intentionally submitted for inclusion in the Work\n      by You to the Licensor shall be under the terms and conditions of\n      this License, without any additional terms or conditions.\n      Notwithstanding the above, nothing herein shall supersede or modify\n      the terms of any separate license agreement you may have executed\n      with Licensor regarding such Contributions.\n\n   6. Trademarks. This License does not grant permission to use the trade\n      names, trademarks, service marks, or product names of the Licensor,\n      except as required for reasonable and customary use in describing the\n      origin of the Work and reproducing the content of the NOTICE file.\n\n   7. Disclaimer of Warranty. Unless required by applicable law or\n      agreed to in writing, Licensor provides the Work (and each\n      Contributor provides its Contributions) on an \"AS IS\" BASIS,\n      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n      implied, including, without limitation, any warranties or conditions\n      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n      PARTICULAR PURPOSE. You are solely responsible for determining the\n      appropriateness of using or redistributing the Work and assume any\n      risks associated with Your exercise of permissions under this License.\n\n   8. Limitation of Liability. In no event and under no legal theory,\n      whether in tort (including negligence), contract, or otherwise,\n      unless required by applicable law (such as deliberate and grossly\n      negligent acts) or agreed to in writing, shall any Contributor be\n      liable to You for damages, including any direct, indirect, special,\n      incidental, or consequential damages of any character arising as a\n      result of this License or out of the use or inability to use the\n      Work (including but not limited to damages for loss of goodwill,\n      work stoppage, computer failure or malfunction, or any and all\n      other commercial damages or losses), even if such Contributor\n      has been advised of the possibility of such damages.\n\n   9. Accepting Warranty or Additional Liability. While redistributing\n      the Work or Derivative Works thereof, You may choose to offer,\n      and charge a fee for, acceptance of support, warranty, indemnity,\n      or other liability obligations and/or rights consistent with this\n      License. However, in accepting such obligations, You may act only\n      on Your own behalf and on Your sole responsibility, not on behalf\n      of any other Contributor, and only if You agree to indemnify,\n      defend, and hold each Contributor harmless for any liability\n      incurred by, or claims asserted against, such Contributor by reason\n      of your accepting any such warranty or additional liability.\n\n   END OF TERMS AND CONDITIONS\n\n   Copyright 2023, Alejandro Ramallo    .\n\n   Licensed under the Apache License, Version 2.0 (the \"License\");\n   you may not use this file except in compliance with the License.\n   You may obtain a copy of the License at\n\n       http://www.apache.org/licenses/LICENSE-2.0\n\n   Unless required by applicable law or agreed to in writing, software\n   distributed under the License is distributed on an \"AS IS\" BASIS,\n   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n   See the License for the specific language governing permissions and\n   limitations under the License.","ref":"license.html"}],"proglang":"erlang","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}